@@ -228,7 +228,7 @@ use XAO::Utils;
 use XAO::Objects;
 
 use vars qw($VERSION);
-$VERSION='1.02';
+$VERSION='1.03';
 
 use base XAO::Objects->load(objname => 'Web::FS');
 
@@ -272,7 +272,7 @@ sub check_mode ($%) {
     }
     else {
         my $config=$self->siteconfig('/content');
-    
+
         $self->SUPER::check_mode(merge_refs({
             'base.database'     => $config->{list_uri} || '/Content',
             'uri'               => $args->{name},
@@ -301,7 +301,7 @@ sub content_add ($%) {
     my $config=$self->siteconfig('/content');
     my $list_uri=$config->{list_uri} || '/Content';
     my $content_list=$self->odb->fetch($list_uri);
-    
+
     my @fields=(
         {   name        => 'name',
             style       => 'text',
@@ -883,10 +883,12 @@ sub content_store ($%) {
     my $data_list=$content->get('Data');
     my $data=$data_list->get_new();
 
-    $data->put(text => $text);
-    $data->put(comment => $comment);
-    $data->put(mime_type => $mime_type);
-    $data->put(mod_time => time);
+    $data->put(
+        text        => $text,
+        comment     => $comment,
+        mime_type   => $mime_type,
+        mod_time    => time,
+    );
 
     my $preview_id=$content->get('preview_id');
     if($preview_id) {
@@ -1106,7 +1108,7 @@ sub get_content ($%) {
     my $config=$self->siteconfig('/content');
     my $list_uri=$config->{list_uri} || '/Content';
     my $flag_cb_uri=$config->{flag_cb_uri} || '/content/preview_flag';
-    
+
     my $name=$args->{name};
     my $data_id=$args->{data_id} || '';
     my $preview=$args->{preview} ||
